from django.core.cache import cache
from django.contrib.messages import constants


def message_user(user, message, level=constants.INFO):
    """
    Send a message to a particular user.

    :param user: User instance
    :param message: Message to show
    :param level: Message level
    """
    cache.set(_user_key(user), (message, level))


def message_users(users, message, level=constants.INFO):
    """
    Send a message to a group of users.

    :param users: Users queryset 
    :param message: Message to show
    :param level: Message level
    """
    for user in users:
        message_user(user, message, level)


def get_message(user):
    """
    Fetch a message for given user.  Returns None if no such message exists.

    :param user: User instance
    """
    key = _user_key(user)
    result = cache.get(key)
    if result:
        cache.delete(key)
        return result[0], result[1]
    return None, None


def _user_key(user):
    return '_async_message_%d' % user.id



#!/usr/bin/env python
from setuptools import setup, find_packages

setup(name='django-async-messages',
      version='0.1.4',
      url='https://github.com/codeinthehole/django-async-messages',
      author="David Winterbottom",
      author_email="david.winterbottom@gmail.com",
      description="Send asynchronous messages to users (eg from offline scripts).  Useful for integration with Celery",
      long_description=open('README.rst').read(),
      packages=find_packages(exclude=['tests']),
      install_requires=['django>=1.2'],
      )



from django.contrib import messages

from async_messages import get_message


class AsyncMiddleware(object):

    def process_response(self, request, response):
        # Check for message for this user and, if it exists,
        # call the messages API with it
       if hasattr(request, "session") and request.user.is_authenticated():
            msg, level = get_message(request.user)
            if msg:
                messages.add_message(request, level, msg)
       return response
